@@ -439,7 +439,7 @@ def vista_get_entire_dataframe():
   vista_final_dataframe = vista_master_dataframe(slugs)
   return vista_final_dataframe
 
-def vista_weekly_update_script(sql_user,sql_pw,sql_db,sql_db_url,search_api_wait=10)
+def vista_weekly_update_script(sql_user,sql_pw,sql_db,sql_db_url,search_api_wait=10):
 
     vista_search_data = vista_search_locations(get_all=True,wait_time=search_api_wait)
 
@@ -482,15 +482,15 @@ def vista_weekly_update_script(sql_user,sql_pw,sql_db,sql_db_url,search_api_wait
         all_object_types = all_object_types[all_object_types[0]=='object'].index
 
         for column in all_object_types:
-        vista_newly_added_df[column] = vista_newly_added_df[column].astype('str')
+          vista_newly_added_df[column] = vista_newly_added_df[column].astype('str')
 
-        engine = create_engine(f"mysql+pymysql://{sql_user}:{sql_pw}@{sql_db_url}/{sql_db}")
+          engine = create_engine(f"mysql+pymysql://{sql_user}:{sql_pw}@{sql_db_url}/{sql_db}")
 
-        for i in range(len(vista_newly_added_df)):
-        try:
-            vista_newly_added_df.iloc[i:i+1].to_sql(name='VISTA_MASTER',if_exists='append',con = engine,index=False)
-        except IntegrityError:
-            pass  
+          for i in range(len(vista_newly_added_df)):
+            try:
+              vista_newly_added_df.iloc[i:i+1].to_sql(name='VISTA_MASTER',if_exists='append',con = engine,index=False)
+            except IntegrityError:
+              pass  
 
 
     # Update Delisted homes in a different table
@@ -505,10 +505,10 @@ def vista_weekly_update_script(sql_user,sql_pw,sql_db,sql_db_url,search_api_wait
         vista_delisted['delisted_on'] = datetime.datetime.today()
 
         for i in range(len(vista_delisted)):
-            try:
-                vista_delisted.iloc[i:i+1].to_sql(name='VISTA_DELISTED',if_exists='append',con = engine,index=False)
-            except IntegrityError:
-                pass  
+          try:
+            vista_delisted.iloc[i:i+1].to_sql(name='VISTA_DELISTED',if_exists='append',con = engine,index=False)
+          except IntegrityError:
+            pass  
 
 
     engine.dispose()
@@ -537,3 +537,5 @@ def final_test():
 
 
 
+
+
